@@ -1,10 +1,8 @@
 import datetime
-from pprint import pprint
 
 import click
 
-from .schemas import Satellite, Tle, Location, PassType
-from .timefn import truncate_datetime, get_date
+from .schemas import Satellite, Location, PassType
 from .geocoding import geocoder
 from .utils import get_TLE, Cache
 from .predictions import predict
@@ -29,24 +27,21 @@ def main(satellite_id, location_string, utc_offset, days, latitude, longitude, h
     data = geocoder(location_string)      # Prompt for location
     tz = datetime.timezone(datetime.timedelta(hours=utc_offset))
     location = Location(
-        lat=float(data['lat']),
-        lon=float(data['lon']),
+        lat=round(float(data['lat']), 4),
+        lon=round(float(data['lon']), 4),
         h=0.0,
         name=location_string
     )
     satellite = Satellite(
         id=satellite_id,
     )
-    tle = get_TLE(satellite)
+    tle = get_TLE(satellite.id)
     date_start = datetime.date.today()
     date_end = date_start + datetime.timedelta(days=days)
     min_elevation = 10.01 # degrees
     cache = Cache() if not no_cache else None
     overpasses = predict(location, satellite, date_start=date_start, date_end=date_end, dt_seconds=1, min_elevation=min_elevation, verbose=verbose, cache=cache, print_fn=echo)
     overpass_table(overpasses, location, tle, tz, twelvehour=twelve, alltypes=alltypes, quiet=quiet)
-    if cache is not None:
-        with cache:
-            cache.flush()
     return 0
 
 
@@ -67,7 +62,7 @@ def overpass_table(overpasses, location, tle, tz=None, twelvehour=False, alltype
     table_title = ""
     table_header = ""
     if not quiet:
-        satellite_id = tle.satellite.id
+        satellite_id = tle.satid
         # Print datetimes with the correct timezone
         table_title += f"Satellite ID {satellite_id} overpasses for {location.name:s}\n"
         table_title += f"Lat={location.lat:.4f}\u00B0, Lon={location.lon:.4f}\u00B0, Timezone {tz}\n"
@@ -82,8 +77,8 @@ def overpass_table(overpasses, location, tle, tz=None, twelvehour=False, alltype
         #   Time   Elx Azx
         point_header = "  Time   El  Az "
         point_header_underline = "-------- --- ---"
-    table_header +=  f"            {'Start':^17s}   {'Maximum':^17s}   {'End':^17s}\n"
-    table_header +=  "  Date    Mag   {0}   {0}   {0}      Type\n".format(point_header)
+    table_header +=  f"           {'Start':^17s}   {'Maximum':^17s}   {'End':^17s}\n"
+    table_header +=  "  Date    Mag  {0}   {0}   {0}      Type\n".format(point_header)
     table_header += "--------  ----  "
     table_header += point_header_underline + " "*3
     table_header += point_header_underline + " "*3
@@ -120,14 +115,6 @@ def overpass_table(overpasses, location, tle, tz=None, twelvehour=False, alltype
         click.secho(table_data, fg=fg)
 
     
-# --------- --- ---
-
-def plot_elevation(date, elevation):
-    import matplotlib.pyplot as plt
-    plt.plot(date, elevation)
-    plt.grid()
-    plt.show()
-
 def echo(*a, **kw):
     if 'end' in kw:
         kw.pop('end')
