@@ -1,13 +1,13 @@
 # models.py
 from dataclasses import dataclass
-from functools import update_wrapper, cached_property
+from functools import cached_property
 import math
 
 import numpy as np
 from astropy.time import Time
 
 from .schemas import Location, Point, Overpass, PassType
-from .constants import RAD2DEG, R_EARTH
+from .constants import RAD2DEG
 from .rotations import ecef2sez
 from .topocentric import site_ECEF
 from .timefn import jday2datetime
@@ -121,9 +121,9 @@ class RhoVector():
     def point(self, idx):
         return Point.construct(
             datetime=jday2datetime(self.time.jd[idx]),
-            azimuth=self.az(idx),
-            elevation=self.el[idx],
-            range=self.rng[idx]
+            azimuth=round(self.az(idx), 3),
+            elevation=round(self.el[idx], 3),
+            range=round(self.rng[idx], 4)
         )
 
     def _start_end_index(self, x):
@@ -137,17 +137,13 @@ class RhoVector():
         end_idx = np.nonzero(x_change_sign & (x0 > x1))[0]    # Find the end of an overpass
         return start_idx, end_idx
 
-    def brightness(self, idx, sun_rho):
-        """
-        Compute the brightness magnitude of the satellite
-        """
-        assert self.sun is not None
-        # find phase angle between observer -- satellite -- sun
-        gamma = self.el[idx] - sun_el[idx]
-        
-        
-
-        
+    # def brightness(self, idx, sun_rho):
+    #     """
+    #     Compute the brightness magnitude of the satellite
+    #     """
+    #     assert self.sun is not None
+    #     # find phase angle between observer -- satellite -- sun
+    #     gamma = self.el[idx] - sun_el[idx]
 
     def find_overpasses(self, min_elevation=10, store_sat_id=False, sunset_el=-6):
         start_idx, end_idx = self._start_end_index(self.el - min_elevation)
@@ -209,28 +205,28 @@ class RhoVector():
             if (passtype is not None) and (passtype == PassType.visible):
                 overpass_dict['vis_start_pt'] = vis_start_pt
                 overpass_dict['vis_end_pt'] = vis_end_pt
-                overpass_dict['brightness'] = brightness
+                overpass_dict['brightness'] = round(brightness, 3)
             overpass_dict['type'] = passtype
             overpass = Overpass.construct(**overpass_dict)
             sat_overpasses[j] = overpass
         return sat_overpasses
 
 
-class SatelliteRV():
-    __slots__ = ['satellite','tle','rsun','datetime','julian_date','rECEF',
-                 'rECI','latitude','longitude','altitude','visible']
-    def __init__(self):
-        self.satellite = None
-        self.tle = None
-        self.rsun = None
-        self.datetime = None
-        self.julian_date = None
-        self.rECEF = None
-        self.rECI = None
-        self.latitude = None
-        self.longitude = None
-        self.altitude = None
-        self.visible = None
+# class SatelliteRV():
+#     __slots__ = ['satellite','tle','rsun','datetime','julian_date','rECEF',
+#                  'rECI','latitude','longitude','altitude','visible']
+#     def __init__(self):
+#         self.satellite = None
+#         self.tle = None
+#         self.rsun = None
+#         self.datetime = None
+#         self.julian_date = None
+#         self.rECEF = None
+#         self.rECI = None
+#         self.latitude = None
+#         self.longitude = None
+#         self.altitude = None
+#         self.visible = None
 
 
 
