@@ -1,22 +1,15 @@
-import pickle
 from datetime import datetime, timedelta
 from typing import List
 import time
 
-import numpy as np
-from numpy import dot, cross
-from numpy.linalg import norm
-from astropy import units as u
-from astropy.coordinates import TEME, CartesianRepresentation, ITRS, get_sun
 from astropy.time import Time
 
-from .rotations import ecef2sez
-from .solar import sun_pos, is_sat_illuminated, compute_sun_data
-from .propagate import propagate_satellite, compute_satellite_data
-from .timefn import julian_date, compute_time_array, julian_day, compute_time_array_from_date
-from .schemas import Overpass, Satellite, Location, Tle
-from .models import Sun, RhoVector, Sat, SatPredictData, SunPredictData
-from .utils import get_TLE, Cache
+from .solar import compute_sun_data
+from .propagate import compute_satellite_data
+from .timefn import compute_time_array_from_date
+from .schemas import Overpass, Location
+from .models import Sun, RhoVector, Sat
+from .utils import get_TLE
 
 
 def find_overpasses(t: Time, location: Location, sats: List[Sat], sun: Sun, min_elevation: float = 10) -> List[Overpass]:
@@ -24,7 +17,7 @@ def find_overpasses(t: Time, location: Location, sats: List[Sat], sun: Sun, min_
     Real-time computation for finding satellite overpasses of a topographic location.
     Can support multiple satellites over a single location
     """
-    store_sat_id = True if len(sats) > 0 else False
+    store_sat_id = True if len(sats) > 1 else False
     overpasses = []
     for sat in sats:
         rho = RhoVector(t, sat, location, sun)
@@ -55,10 +48,8 @@ def predict(location, satellite, date_start=None, date_end=None, dt_seconds=1, m
     if cache is None:
         t = compute_time_array_from_date(date_start, date_end, dt_seconds)
         sun = compute_sun_data(t)
-        sun = SunPredictData(rECEF=sun.rECEF)
-        tle = get_TLE(satellite)
+        tle = get_TLE(satellite.id)
         sat = compute_satellite_data(tle, t, sun)
-        sat = SatPredictData(id=sat.id, rECEF=sat.rECEF, illuminated=sat.illuminated)
 
     else:
 
@@ -78,7 +69,6 @@ def predict(location, satellite, date_start=None, date_end=None, dt_seconds=1, m
                     print_fn("Compute sun position... ", end=' ')
                 t0 = time.perf_counter()
                 sun = compute_sun_data(t)
-                sun = SunPredictData(rECEF=sun.rECEF)
                 tf = time.perf_counter() - t0
                 if verbose:
                     print_fn(f'{tf:0.3f} sec')
@@ -87,7 +77,7 @@ def predict(location, satellite, date_start=None, date_end=None, dt_seconds=1, m
             tle_key = str(satellite.id) + '_tle'
             tle = cache.get(tle_key)
             if tle is None:
-                tle = get_TLE(satellite)
+                tle = get_TLE(satellite.id)
                 cache.set(tle_key, tle, ttl=86400)
 
             sat_key = tle_key + time_key + '_sat'
@@ -97,7 +87,6 @@ def predict(location, satellite, date_start=None, date_end=None, dt_seconds=1, m
                     print_fn(f"Propagate satellite from {date_start.isoformat()} to {date_end.isoformat()}... ", end=' ')
                 t0 = time.perf_counter()
                 sat = compute_satellite_data(tle, t, sun)
-                sat = SatPredictData(id=sat.id, rECEF=sat.rECEF, illuminated=sat.illuminated)
                 tf = time.perf_counter() - t0
                 if verbose:
                     print_fn(f'{tf:0.3f} sec')
