@@ -1,7 +1,6 @@
 # schemas
 import datetime
-from dataclasses import dataclass
-from typing import Any, List
+from typing import List
 from enum import Enum
 
 import numpy as np
@@ -61,14 +60,6 @@ class Satellite(BaseModel):
     name: str = None
 
 
-class SatelliteCategory(str, Enum):
-    military = 'military'
-    communication = 'communication'
-    earth_observing = 'earth observing'
-    space_science = 'space science'
-
-
-
 class SatelliteDetails(BaseModel):
     id = int   # NORAD ID
     name: str = None
@@ -82,8 +73,6 @@ class SatelliteDetails(BaseModel):
     launch_date: datetime.date = None
     launch_site: str = None
     mass: float = None   # kg
-    perigee: float = None  # km
-    apogee: float = None   # km
 
 
 
@@ -92,7 +81,7 @@ class Tle(BaseModel):
     tle1: str
     tle2: str
     epoch: datetime.datetime
-    satellite: Satellite
+    satid: int
 
 
 class PassType(str, Enum):
