@@ -1,6 +1,5 @@
 import json
 import datetime
-import os
 from itertools import zip_longest
 from collections import OrderedDict
 from typing import NamedTuple
@@ -67,6 +66,13 @@ def epoch_from_tle(tle1: str) -> datetime.datetime:
     return epoch_from_tle_datetime(epoch_string)
     
 
+def satid_from_tle(tle1: str) -> int:
+    """
+    Extract satellite NORAD ID as int from tle line 1
+    """
+    return int(tle1[2:7])
+
+
 def get_orbit_data_from_celestrak(satellite_id):
     """
 
@@ -123,16 +129,16 @@ def parse_tle(tle_string_list):
     """
     tle0, tle1, tle2 = tle_string_list
     name = tle0.strip()  # satellite name
-    satellite_id = tle1[2:7]
+    satellite_id = satid_from_tle(tle1)
     return {satellite_id : {'name': name, 'tle1': tle1, 'tle2': tle2}}
 
 
-def get_TLE(satellite, tle_data=None):
-    tle_data = parse_tles_from_celestrak(satellite.id)
-    tle1 = tle_data[str(satellite.id)]['tle1']
-    tle2 = tle_data[str(satellite.id)]['tle2']
+def get_TLE(satid: int, tle_data=None):
+    tle_data = parse_tles_from_celestrak(satid)
+    tle1 = tle_data[satid]['tle1']
+    tle2 = tle_data[satid]['tle2']
     epoch = epoch_from_tle(tle1)
-    tle = Tle(tle1=tle1, tle2=tle2, epoch=epoch, satellite=satellite)
+    tle = Tle(tle1=tle1, tle2=tle2, epoch=epoch, satid=satid)
     return tle
 
 
@@ -173,15 +179,13 @@ class CacheItem(NamedTuple):
 
 class Cache:
     data_cache_filename = 'cache_data.db'
-    indices = {  # index table name: index item name
-        'ttl': 'timestamp',
-        'cat': 'category',
-      }
+    data_index_filename = 'cache_index.db'
         
     def __init__(self, cache_directory='.passpredict_cache', ttl=84600):   
         self.directory = cache_directory
         self.dir_path = Path(cache_directory)
         self.ttl_default = ttl
+        self.ttl = None
         self.cache = None
         self.category = None
 
@@ -191,17 +195,14 @@ class Cache:
     def set(self, key, value, ttl: int = 0, category: DataCategory = None):
         key_hash = self.hash(key)
         timestamp = self._get_ttl_timestamp(ttl)
-        # if key_hash in self.cache:
-        #     old_item = self.cache[key_hash]
-        #     # Remove old item from indices
-        #     for index_tbl, index_field in self.indices:
-        #         self.pop_index_item(index_tbl, old_item.__dict__() )
-        #     old_timestamp = old_item.timestamp
-        #     if old_timestamp is not None:
-        #         self.ttl[old_timestamp].remove(key_hash)
+        if key_hash in self.cache:
+            old_item = self.cache[key_hash]
+            old_timestamp = old_item.timestamp
+            if old_timestamp is not None:
+                self.ttl[old_timestamp].remove(key_hash)
         self.cache[key_hash] = CacheItem(data=value, ttl=ttl, timestamp=timestamp, category=category)
-        # if ttl > 0:
-        #     self._set_ttl(key_hash, timestamp)
+        if ttl > 0:
+            self._set_ttl(key_hash, timestamp)
         
             
     def _set_ttl(self, key_hash, timestamp: int):
@@ -220,50 +221,15 @@ class Cache:
         else:
             return item.data
 
-    def pop(self, key, default_value=None, index=None):
+    def pop(self, key, default_value=None):
         key_hash = self.hash(key)
         if key_hash in self.cache:
             value = self.get(key)
             del self.cache[key_hash]
-            # if index is not None:
-            #     self.pop_index_item(index, )
             return value
         else:
             return default_value
 
-    def get_index_items(self, index, index_key):
-        index_dict = self.cache[index + '_index']
-        return index_dict.get(index_key)
-
-    def set_index_item(self, index, index_key, index_item):
-        key = index + '_index'
-        index_dict = self.cache[key]
-        index_result = index_dict.get(index_key, set())
-        index_result += {index_item}
-        index_dict.update({
-            index_key: index_result
-        })
-        self.cache[key] = index_dict
-
-    def remove_item_from_cache(self, item):
-        pass
-
-    def pop_index_item(self, index, index_key, index_item):
-        key = index + '_index'
-        index_dict = self.cache[key]
-        index_result = index_dict.get(index_key, set())
-        if index_item in index_result:
-            index_result.remove(index_item)
-        if len(index_result) == 0:
-            index_dict.pop(index_key)
-        else:
-            index_dict.update({
-                index_key: index_result
-            })
-        self.cache[key] = index_dict
-
-        
-
     def __contains__(self, key):
         key_hash = self.hash(key)
         return key_hash in self.cache
@@ -279,16 +245,7 @@ class Cache:
 
     def flush(self):
         """Remove expired cache entires"""
-        current_time = time.time()
-        for key, value in self.cache.items():
-            t = value.timestamp
-            if (t is not None) and (current_time > t):
-                del self.cache[key]
-        # ttl_index_dict = self.cache['ttl_index']
-        # current_timestamp = time.time()
-        # expired_keys = (key for key in ttl_index_dict.keys() if key >= current_timestamp)
-        # for key in expired_keys:
-
+        pass
 
     def __enter__(self, *a, **kw):
         return self.open()
@@ -296,19 +253,14 @@ class Cache:
     def __exit__(self, *a, **kw):
         self.close()
 
-    def _build_indices(self):
-        for idx, _ in self.indices:
-            key = idx + '_index'
-            self.cache[key] = OrderedDict()
-
-    # def _open_ttl(self):
-    #     self.ttl_path = self.dir_path / self.data_index_filename
-    #     if self.ttl_path.exists():
-    #         with open(self.ttl_path, 'rb+') as f:
-    #             self.ttl = pickle.load(f)
-    #     else:
-    #         self.ttl = OrderedDict()
-    #         self._build_ttl_index()
+    def _open_ttl(self):
+        self.ttl_path = self.dir_path / self.data_index_filename
+        if self.ttl_path.exists():
+            with open(self.ttl_path, 'rb+') as f:
+                self.ttl = pickle.load(f)
+        else:
+            self.ttl = OrderedDict()
+            self._build_ttl_index()
 
     def open(self):
         """
@@ -320,13 +272,13 @@ class Cache:
             dir_path.mkdir()
         cache_path = dir_path / self.data_cache_filename
         self.cache = shelve.DbfilenameShelf(str(cache_path))
-        # self._open_ttl()
+        self._open_ttl()
         return self
         
     def close(self):
         self.cache.close()
-        # with open(self.ttl_path, 'wb') as f:
-        #     pickle.dump(self.ttl, f)
+        with open(self.ttl_path, 'wb') as f:
+            pickle.dump(self.ttl, f)
 
     def _build_ttl_index(self):
         """Iterate through cache and build ttl index"""
